==> schlix-cms-v2.1.8-7.zip: schlix/install/step_welcome.template.php <==
<div id="install_welcome">
    <div class="row">
        <div class="col-md-6">
            <h1>Welcome!</h1>
            <p>Thank you for downloading SCHLIX CMS. We hope you find this product easy to use and  help you with your goal building a website that works for you! If you have any questions or comments, please <a href="https://www.schlix.com/forum/" target="_blank">let us know</a>. We always accept constructive feedback on how to improve this product.</p>

            <p>This is a barebone content management system that comes with minimal add-ons. To get more extensions, visit our <a href="https://www.schlix.com/extensions/" target="_blank">Extensions Directory</a>. You can also <a href="https://www.schlix.com/extensions/development/plugin-creator.html">create and publish your own extension</a>. </p>
            <p>For best result, please use Firefox 45+, Chrome 35+, Opera 37+, or Internet Explorer Edge 14.0 as SCHLIX CMS requires <strong>Ecmascript 6</strong> compatible web browser for all the administration functions</p>   

            <p>By installing this product, you agree to adhere the following license agreement:</p>


        </div>

        <div class="col-md-6">
            <div id="changelog">
                <?php include ('changelog.html'); ?>
            </div>

        </div>        
    </div>

    <div class="clearfix"></div>
</div>
<div class="clearboth"></div>
<?php if ($this->isUserInstallingSchlixOnDefaultFolder()): ?>
    <p>Notice: You seem to be installing Schlix using the default folder called 'schlix'. You can actually rename the folder to 'mywebsite' or 'site' or whatever you'd like. You can even move it to the root folder too. If you want to rename it first, go ahead and then reload the page using the renamed base URL. Otherwise you can press Next to continue</p>
<?php endif; ?>
<!-- end tabs -->
<div id="license">
    <?php include ('../license.html'); ?>
</div>
<div align="center">
    <form id="form1" name="form1" method="post" action="index.php?action=requirement">
        <div class="text-left" style="margin:0 auto;display:inline-block">
            <div class="radio">
                <label><input type="radio" name="agreement" class="validate-one-required" id="agree" value="yes" onclick="document.getElementById('submitbutton').disabled = false;" <?php if ($_SESSION['agree'] == 'yes') echo ' checked'; ?> required="required" />Yes, I agree and would like to continue installing this software</label></div>
            <div class="radio">    
                <label><input type="radio" name="agreement" class="validate-one-required" id="disagree" value="0" onclick="document.getElementById('submitbutton').disabled = true;" required="required" />No, I disagree and do not want to continue</label><br/></div>
        </div>
        <div class="text-center">        
            <button type="submit" name="submit" id="submitbutton" class="btn btn-success" value="Submit" /><i class="fa fa-arrow-circle-right"></i> Submit</button>

        </div>

    </form>
</div>

==> schlix-cms-v2.2.2-1.zip: schlix/install/step_welcome.template.php <==
<?php
if (!defined('SCHLIX_INSTALLER')) die('Please visit /install/');
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC.
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
?>
<div id="install_welcome">
    <div class="row">
        <div class="col-md-6">
            <h1>Welcome!</h1>
            <p>Thank you for downloading SCHLIX CMS. We hope you find this product easy to use and  help you with your goal building a website that works for you! If you have any questions or comments, please <a href="https://www.schlix.com/forum/" target="_blank">let us know</a>. We always accept constructive feedback on how to improve this product.</p>

            <p>This is a barebone content management system that comes with minimal add-ons. To get more extensions, visit our <a href="https://www.schlix.com/extensions/" target="_blank">Extensions Directory</a>. You can also <a href="https://www.schlix.com/extensions/development/plugin-creator.html">create and publish your own extension</a>. </p>
            <p>For best result, please use Firefox 45+, Chrome 35+, Opera 37+, or Internet Explorer Edge 14.0 as SCHLIX CMS requires <strong>Ecmascript 6</strong> compatible web browser for all the administration functions</p>   

            <p>By installing this product, you agree to adhere the following license agreement:</p>


        </div>

        <div class="col-md-6">
            <div id="changelog">
                <?php include ('changelog.html'); ?>
            </div>

        </div>        
    </div>

    <div class="clearfix"></div>
</div>
<div class="clearboth"></div>
<?php if ($this->isUserInstallingSchlixOnDefaultFolder()): ?>
    <p>Notice: You seem to be installing Schlix using the default folder called 'schlix'. You can actually rename the folder to 'mywebsite' or 'site' or whatever you'd like. You can even move it to the root folder too. If you want to rename it first, go ahead and then reload the page using the renamed base URL. Otherwise you can press Next to continue</p>
<?php endif; ?>
<!-- end tabs -->
<div id="license">
    <?php include ('../license.html'); ?>
</div>
<div align="center">
    <form id="form1" name="form1" method="post" action="index.php?action=requirement" class="form-install" >
        <div class="text-left" style="margin:0 auto;display:inline-block">
            <div class="radio">
                <label><input type="radio" name="agreement" class="validate-one-required" id="agree" value="yes" onclick="document.getElementById('submitbutton').disabled = false;" <?php if ($_SESSION['agree'] == 'yes') echo ' checked'; ?> required="required" />Yes, I agree and would like to continue installing this software</label></div>
            <div class="radio">    
                <label><input type="radio" name="agreement" class="validate-one-required" id="disagree" value="0" onclick="document.getElementById('submitbutton').disabled = true;" required="required" />No, I disagree and do not want to continue</label><br/></div>
        </div>
        <div class="text-center">        
            <button type="submit" name="submit" id="submitbutton" class="btn btn-success" value="Submit" /><i class="fas fa-arrow-circle-right"></i> Submit</button>

        </div>

    </form>
</div>
